@@ -2,7 +2,7 @@ import pytest
 from aleph_alpha_client.aleph_alpha_client import AlephAlphaClient, AsyncClient, Client
 from aleph_alpha_client.aleph_alpha_model import AlephAlphaModel
 from aleph_alpha_client.completion import CompletionRequest
-from aleph_alpha_client.prompt import Prompt, Text, TextControl
+from aleph_alpha_client.prompt import ControlTokenOverlap, Prompt, Text, TextControl
 
 from tests.common import (
     client,
@@ -40,7 +40,15 @@ def test_complete(sync_client: Client, model_name: str):
             [
                 Text(
                     "Hello, World!",
-                    controls=[TextControl(start=1, length=5, factor=0.5)],
+                    controls=[
+                        TextControl(start=1, length=5, factor=0.5),
+                        TextControl(
+                            start=1,
+                            length=5,
+                            factor=0.5,
+                            token_overlap=ControlTokenOverlap.Complete,
+                        ),
+                    ],
                 )
             ]
         ),
